import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import com.jinsight.jetchart.*;

/**
 *
 * This demo displays one image series.
 *
 * @author Andre de Lima Soares - alsoares@jinsight.com
 */ 
public class Main extends JFrame implements ItemListener {
    Graph graph;
    ImageSerie is;

    JCheckBox isHorizontal;

    public Main() {
	
	// A title for the frame
	setTitle("The JetChart Library - Image Chart Demo");
	
	// Values for the series
	double[] values={400,70,130,250};

	// Creates Image Series.
	Image img1=getToolkit().getImage("floppy.gif");
	Image img2=getToolkit().getImage("cdrom.gif");
	Image img3=getToolkit().getImage("floppy.gif");
	Image img4=getToolkit().getImage("cdrom.gif");
	Image[] images={img1,img2,img3,img4};	
	is=new ImageSerie(values,images);
	
	// Labels for chart
	String[] labels={"floppy","cd-rom","floppy","cd-rom"};

	// Creates graphic context, passing labels
	graph=new Graph(labels);

	// Sets chart optional properties
	setChartProperties();

	// Adds the image series  to the graphic context
	graph.addSerie(is);

        Container ct=getContentPane();

	ct.add("Center",graph);

	// Creates a top panel to lay out components
	createTopPanel();

	// Adds window adapter
	addWindowListener(new WindowAdapter() {
	    public void windowClosing(WindowEvent evt) {
		System.exit(0);
	    }
	});

	setSize(400,400);

	// Centers frame on the screen
	Dimension d=getToolkit().getScreenSize();
	setLocation((d.width-getSize().width)/2,(d.height-getSize().height)/2);

	setVisible(true);

    }

    // Event handler for  chart orientation
    public void itemStateChanged(ItemEvent evt) {
	boolean hor=isHorizontal.isSelected();
	graph.setHorizontalGraphEnabled(hor);
	if (!hor) {
	    graph.getLeftTitle().setText("Values Title");
	    graph.getBottomTitle().setText("Labels Title");
	}
	else {
	    graph.getLeftTitle().setText("Labels Title");
	    graph.getBottomTitle().setText("Values Title");
	}
	graph.repaint();
    }

	    
    // Creates top panel
    private void createTopPanel( ) {

	// Creates top panel with a border around
	JPanel topPanel=new JPanel();

	topPanel.setLayout(new FlowLayout(FlowLayout.LEFT));
	
	// Checkbox for chart orientation property
	isHorizontal=new JCheckBox("Horizontal");
	isHorizontal.setFont(new Font("Arial",Font.PLAIN,10));
	isHorizontal.addItemListener(this);

	topPanel.add(isHorizontal);

        Container ct=getContentPane();

	ct.add("North",topPanel);

    }

    private void setChartProperties() {

	// Sets gradient colors
	graph.setGradientColors(Color.white,Color.gray);

	// Enables tooltip
	graph.getToolTip().setEnabled(true);
	
	// Sets chart title
	String[] title={"The JetChart Library","Image series demo"};
	graph.setTitle(title);
	
	// Sets labels title
	graph.getLeftTitle().setText("Labels Title");

	// Sets values title
	graph.getBottomTitle().setText("Values Title");

	// Enables chart and legend dragging. A double-click over chart alternates
	// between moving chart and scale adjustment.
	graph.setDraggingEnabled(true);

	// Enables grid and sets grid color. See the GraphSet class documentation for
	// further details.
	graph.getGraphSet(0).getGrid().setEnabled(true);
	graph.getGraphSet(0).getGrid().setColor(Color.blue);

	// Sets format for tooltips values.
	graph.setValueFormat("###,###0.00");

    }


    public static void main(String[] args) {
	new Main();
    }
}
